@@ -1,24 +1,24 @@
 use strict;
 use warnings;
 package Finance::FXCM::Simple;
-$Finance::FXCM::Simple::VERSION = '0.011';
+$Finance::FXCM::Simple::VERSION = '0.012';
 require XSLoader;
 XSLoader::load(
     'Finance::FXCM::Simple',
     $Finance::FXCM::Simple::{VERSION} ? ${ $Finance::FXCM::Simple::{VERSION} } : ()
 );
 
-use YAML::Syck;
+use YAML::XS;
 
 sub getTrades {
     my ($self) = @_;
-    my $trades = YAML::Syck::Load($self->getTradesAsYAML());
+    my $trades = Load($self->getTradesAsYAML());
     return $trades;
 }
 
 sub getOffersHash {
     my ($self) = @_;
-    my $trades = YAML::Syck::Load($self->getOffersHashAsYAML());
+    my $trades = Load($self->getOffersHashAsYAML());
     return $trades;
 }
 
